@@ -133,7 +133,7 @@ class CogEnvDecoder:
         # return img
 
 
-    def _GetImg(imgData):
+    def _GetImg(self, imgData):
         img_length = int(imgData[90000])
         if img_length > 0:
             float_img = np.asarray(imgData[0:img_length], dtype=np.uint8)
